![GitHub License](https://img.shields.io/github/license/r0b4dams/authexchange?)
[![CI](https://github.com/r0b4dams/authexchange/actions/workflows/ci.yaml/badge.svg)](https://github.com/r0b4dams/authexchange/actions/workflows/ci.yaml)
[![Tests](https://github.com/r0b4dams/authexchange/actions/workflows/unit_tests.yaml/badge.svg)](https://github.com/r0b4dams/authexchange/actions/workflows/unit_tests.yaml)

[![GitHub Release](https://img.shields.io/github/v/release/r0b4dams/authexchange?logo=github&label=GitHub&color=%23fefefe)](https://github.com/r0b4dams/authexchange/releases)
[![PyPI - Version](https://img.shields.io/pypi/v/authexchange?&logo=pypi&label=PyPI&labelColor=%23ffffff&color=%235a9fd4)](https://pypi.org/project/authexchange/)
[![Docker Image Version](https://img.shields.io/docker/v/r0b4dams/authexchange?&logo=docker&logoColor=%231D63ED&label=Docker&labelColor=%23E5F2FC&color=%231D63ED)](https://hub.docker.com/repository/docker/r0b4dams/authexchange)

# authexchange

A server to perform the OAuth token exchange with FusionAuth.